from setuptools import setup, find_packages
setup(
name='external-url-scanner',
version='0.0.1',
author='Subscription-pypi Creatoriq',
author_email='subscription-pypi@creatoriq.com',
description='Packageholdername for add-math functions',
packages=find_packages(),
classifiers=[
'Programming Language :: Python :: 3',
'License :: OSI Approved :: MIT License',
'Operating System :: OS Independent',
],
python_requires='>=3.9',
)
